# Docs Structure Guide
# Rst docs - https://docutils.sourceforge.io/docs/ref/rst/restructuredtext.html
#
# 	1. Place docs in folders under source for different sections
#   2. Link them by adding individual index files in each section 
#      to the main index, and then files for each section to their
#      respective index files.
#   3. Use `.. include` statements to include other .rst files
#      or part of them, or use hyperlinks to a section of the docs,
#      to get rid of repetition.
#      https://docutils.sourceforge.io/docs/ref/rst/directives.html#including-an-external-document-fragment
#   
#   Note: Replace these guide/placeholder docs

.. include:: ../../../README.rst
